package de.thesmile.android.widget.buttons;

import android.app.PendingIntent;
import android.appwidget.AppWidgetManager;
import android.appwidget.AppWidgetProvider;
import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.net.Uri;
import android.text.SpannableString;
import android.text.style.StyleSpan;
import android.text.style.TypefaceSpan;
import android.widget.RemoteViews;
import android.widget.Toast;

public class ButtonWidget extends AppWidgetProvider {

	public static String ACTION_WIDGET_CONFIGURE = "ConfigureWidget";

	@Override
	public void onUpdate(Context context, AppWidgetManager appWidgetManager, int[] appWidgetIds) 
	{
		final int N = appWidgetIds.length;
		for (int i=0; i<N; i++) 
		{
            int appWidgetId = appWidgetIds[i];	  
			updateAppWidget(context, appWidgetManager, appWidgetId);
		}
	}
	
	@Override
    public void onDeleted(Context context, int[] appWidgetIds) 
	{
		Toast.makeText(context, "Deleting Widget...", Toast.LENGTH_SHORT).show();
        // When the user deletes the widget, delete the preference associated with it.
        final int N = appWidgetIds.length;
        for (int i=0; i<N; i++) 
        {
        	ClickOneActivity.deleteTitleAndBodyPref(context, appWidgetIds[i]);
        }
    }
	
	static void updateAppWidget(Context context, AppWidgetManager appWidgetManager, int appWidgetId)
	{		
		Intent configIntent = new Intent(context,  ClickOneActivity.class );
		configIntent.setAction( ACTION_WIDGET_CONFIGURE );
		configIntent.putExtra( AppWidgetManager.EXTRA_APPWIDGET_ID, appWidgetId );
		Uri data = Uri.withAppendedPath(Uri.parse("ButtonWidget://widget/id/#"+appWidgetId), String.valueOf(appWidgetId));
		configIntent.setData(data);
		PendingIntent configPendingIntent = PendingIntent.getActivity(context, 0, configIntent, 0);
		
		RemoteViews remoteViews = new RemoteViews(context.getPackageName(), R.layout.main);
		remoteViews.setOnClickPendingIntent(R.id.button_two, configPendingIntent);
		
		int textColor = ClickOneActivity.loadTextColor(context, appWidgetId);
		int textStyle = ClickOneActivity.loadTextStyle(context, appWidgetId);
		String text   = ClickOneActivity.loadTitlePref(context, appWidgetId);
		String font   = ClickOneActivity.loadTextFont(context, appWidgetId);
		
		SpannableString spannedText = new SpannableString(text);
		spannedText.setSpan(new StyleSpan(textStyle), 0, spannedText.length(), 0);
		spannedText.setSpan(new TypefaceSpan(font), 0, spannedText.length(), 0);	
			
		remoteViews.setTextViewText(R.id.button_two, spannedText);	
		remoteViews.setTextColor(R.id.button_two, textColor);	
		
		if((text.equals("")) || (textColor == Color.TRANSPARENT))
			Toast.makeText(context, "Achtung, durchsichtiges Notiz-Widget vorhanden...", Toast.LENGTH_SHORT).show();
//		else
//			Toast.makeText(context, "Update Text to: \n\"" + text + "\"", Toast.LENGTH_SHORT).show();
//		Toast.makeText(context, "Update wurde aufgerufen", Toast.LENGTH_SHORT).show();
        appWidgetManager.updateAppWidget(appWidgetId, remoteViews);
    }
}
